@@ -17,7 +17,8 @@ from starlette.staticfiles import StaticFiles
 
 from fastapi import FastAPI, Form, Depends, File, UploadFile, Body
 
-app_ = FastAPI(title='AppZoo')  # todo: 全局变量
+
+# app_ = FastAPI(title='AppZoo')  # todo: 全局变量
 
 
 class App(object):
@@ -32,8 +33,8 @@ class App(object):
     """
 
     def __init__(self, verbose=True):
-        # self.app = FastAPI()
-        self.app = app_
+        self.app = FastAPI(title='AppZoo')
+        # self.app = app_
 
         self.verbose = verbose  # 是否返回请求体
 
@@ -82,26 +83,26 @@ class App(object):
         1. 过滤掉 _ 开头的py文件
         2. 支持单文件
         """
+
+        app_home = Path(sys_path_append(app_dir))
+        n = app_home.parts.__len__()
+
+        pattern = Path(app_dir).name if Path(app_dir).is_file() else '*.py'
+
         routes = []
-        if Path(app_dir).is_dir():
-            for p in Path(app_dir).rglob('*.py'):
-                if not p.stem.startswith('_'):  # 过滤_开头的py
-                    route = '/' + str(p)[:-3]
-                    routes.append(route)
+        for p in app_home.rglob(pattern):
+            if not p.stem.startswith('_'):  # 过滤_开头的py
+                home_parts = p.parts[n:]
+                route = '/' + "/".join(home_parts)[:-3]
+                route = str(Path(prefix) / Path(route))
+                routes.append(route)
 
-                    func = importlib.import_module(route.strip('/').replace('/', '.')).main
-                    self.add_route(f"{Path(prefix) / Path(route)}", func, method='POST', **kwargs)
-
-        else:
-            route = app_dir = Path(app_dir).stem
-            routes.append(app_dir)
-
-            func = importlib.import_module(route).main
-            self.add_route(f"{Path(prefix) / Path(route)}", func, method='POST', **kwargs)
+                func = importlib.import_module('.'.join(home_parts)[:-3]).main
+                self.add_route(route, func, method='POST', **kwargs)
 
         logger.info(f"Add Routes: {routes}")
 
-        self.add_route(f'/__{app_dir}', lambda: routes, method='GET', **kwargs)
+        self.add_route(f'/__{app_home.stem}', lambda: routes, method='GET', **kwargs)
         return routes
 
     def _handler(self, func, method='GET', result_key='data', **kwargs):
