@@ -48,5 +48,15 @@ def run(app_file: str, app='fastapi', port=9955, nohup=0):
     _run_cmd(cmd, nohup)
 
 
+# 一键起服务
+@cli.command()
+def easy_run(app_dir: str, port=8000, access_log=True, prefix='/'):
+    from appzoo import App
+
+    app = App()
+    app.add_apps(app_dir, prefix=prefix)
+    app.run(port=port, access_log=access_log)
+
+
 if __name__ == '__main__':
     cli()
