@@ -14,7 +14,7 @@ from meutils.pipe import *
 app = App(False)
 app_ = app.app
 
-app.add_apps()
+app.add_apps('apps', prefix='/xsadasdas')
 
 
 #########################个性化#########################
